@@ -715,6 +715,14 @@ class CronTabber(App):
         exclude_from_dump_conf=True,
     )
 
+    required_config.add_option(
+        name='audit-ghosts',
+        default=False,
+        doc='Checks if there jobs in the database that is not configured.',
+        exclude_from_print_conf=True,
+        exclude_from_dump_conf=True,
+    )
+
     required_config.add_option(
         name='reset-job',
         default='',
@@ -774,6 +782,9 @@ class CronTabber(App):
         elif self.config.get('reset-job'):
             self.reset_job(self.config.get('reset-job'))
             return 0
+        elif self.config.get('audit-ghosts'):
+            self.audit_ghosts()
+            return 0
         elif self.config.get('configtest'):
             if not self.configtest():
                 return 1
@@ -1204,6 +1215,27 @@ class CronTabber(App):
             print >>sys.stderr, ''.join(traceback.format_tb(exc_tb))
             return False
 
+    def audit_ghosts(self):
+        """compare the list of configured jobs with the jobs in the state"""
+        print_header = True
+        for app_name in self._get_ghosts():
+            if print_header:
+                print_header = False
+                print (
+                    "Found the following in the state database but not "
+                    "available as a configured job:"
+                )
+            print "\t%s" % (app_name,)
+
+    def _get_ghosts(self):
+        class_list = self.config.crontabber.jobs.class_list
+        class_list = self._reorder_class_list(class_list)
+        configured_app_names = []
+        for __, job_class in class_list:
+            configured_app_names.append(job_class.app_name)
+        state_app_names = self.job_state_database.keys()
+        return set(state_app_names) - set(configured_app_names)
+
 
 def local_main():
     import sys
