@@ -112,16 +112,13 @@ class IntegrationTestCaseBase(TestCaseBase):
                 configman.ConfigFileFutureProxy,
                 environment,
             ],
-            # app_name='crontabber',
-            # app_name=app.CronTabber.app_name,
             app_name='test-crontabber',
             app_description=__doc__,
-            # argv_source=[]
         )
 
-        with config_manager.context() as config:
-            config.crontabber.logger = mock.Mock()
-            return config
+        config = config_manager.get_config()
+        config.crontabber.logger = mock.Mock()
+        return config
 
     def setUp(self):
         super(IntegrationTestCaseBase, self).setUp()
@@ -187,13 +184,16 @@ class IntegrationTestCaseBase(TestCaseBase):
             'error_count', 'depends_on', 'last_error'
         )
         structure = {}
-        for record in cursor.fetchall():
-            row = dict(zip(columns, record))
-            last_error = row.pop('last_error')
-            if isinstance(last_error, basestring):
-                last_error = json.loads(last_error)
-            row['last_error'] = last_error
-            structure[row.pop('app_name')] = row
+        try:
+            for record in cursor.fetchall():
+                row = dict(zip(columns, record))
+                last_error = row.pop('last_error')
+                if isinstance(last_error, basestring):
+                    last_error = json.loads(last_error)
+                row['last_error'] = last_error
+                structure[row.pop('app_name')] = row
+        finally:
+            self.conn.commit()
         return structure
 
     def _load_logs(self):
@@ -215,7 +215,10 @@ class IntegrationTestCaseBase(TestCaseBase):
             'exc_type', 'exc_value', 'exc_traceback'
         )
         logs = defaultdict(list)
-        for record in cursor.fetchall():
-            row = dict(zip(columns, record))
-            logs[row.pop('app_name')].append(row)
+        try:
+            for record in cursor.fetchall():
+                row = dict(zip(columns, record))
+                logs[row.pop('app_name')].append(row)
+        finally:
+            self.conn.commit()
         return logs
